==> customer-space-portlet-1.2.41-sources.jar: org/exoplatform/cs/portlet/quickticket/package-info.java <==
@Portlet
@Application(name = "QuickTicketController")
@Bindings({ @Binding(value = ListenerService.class), @Binding(value = TicketService.class), @Binding(value = CSSpaceService.class), @Binding(value = EnvironmentService.class) })
@Scripts({
    @Script(id = "jQueryUI", value = "js/lib/jquery-ui.js"),
    // AngularJS is still global, should be AMDified
    @Script(id = "angularjs", value = "js/lib/angular.min.js"),
    @Script(id = "ngSanitize", value = "js/lib/angular-sanitize.js", depends = "angularjs"),
    // services and controllers js are AMD modules, required by controllers.js
    @Script(id = "controllers", value = "js/controllers.js", depends = { "angularjs"}),
    @Script(id = "ticketAddon", value = "js/cs-ticket.js", depends = { "controllers" }) })
@Less("style/cs-ticket.less")
@Stylesheets({ @Stylesheet(id = "jQueryUISkin", value = "style/jquery-ui.css"),
    @Stylesheet(id = "TicketSkin", value = "style/cs-ticket-parent.css") })
@Assets("*")
package org.exoplatform.cs.portlet.quickticket;

import juzu.Application;
import juzu.plugin.asset.Assets;
import juzu.plugin.asset.Script;
import juzu.plugin.asset.Scripts;
import juzu.plugin.asset.Stylesheet;
import juzu.plugin.asset.Stylesheets;
import juzu.plugin.binding.Binding;
import juzu.plugin.binding.Bindings;
import juzu.plugin.less.Less;
import juzu.plugin.portlet.Portlet;

import org.exoplatform.cs.service.CSSpaceService;
import org.exoplatform.cs.service.EnvironmentService;
import org.exoplatform.cs.service.TicketService;
import org.exoplatform.services.listener.ListenerService;

==> customer-space-portlet-1.2.61-sources.jar: org/exoplatform/cs/portlet/quickticket/package-info.java <==
@Portlet
@Application(name = "QuickTicketController")
@Bindings({ @Binding(value = ListenerService.class), @Binding(value = TicketService.class), @Binding(value = CSSpaceService.class), @Binding(value = UploadService.class), @Binding(value = EnvironmentService.class) })
@Scripts({
    @Script(id = "jQueryUI", value = "js/lib/jquery-ui.js"),
    // AngularJS is still global, should be AMDified
    @Script(id = "angularjs", value = "js/lib/angular.min.js"),
    @Script(id = "ngSanitize", value = "js/lib/angular-sanitize.js", depends = "angularjs"),
    // services and controllers js are AMD modules, required by controllers.js
    @Script(id = "controllers", value = "js/controllers.js", depends = { "angularjs"}),
    @Script(id = "ticketAddon", value = "js/cs-ticket.js", depends = { "controllers" }) })
@Less("style/cs-ticket.less")
@Stylesheets({ @Stylesheet(id = "jQueryUISkin", value = "style/jquery-ui.css"),
    @Stylesheet(id = "TicketSkin", value = "style/cs-ticket-parent.css") })
@Assets("*")
package org.exoplatform.cs.portlet.quickticket;

import juzu.Application;
import juzu.plugin.asset.Assets;
import juzu.plugin.asset.Script;
import juzu.plugin.asset.Scripts;
import juzu.plugin.asset.Stylesheet;
import juzu.plugin.asset.Stylesheets;
import juzu.plugin.binding.Binding;
import juzu.plugin.binding.Bindings;
import juzu.plugin.less.Less;
import juzu.plugin.portlet.Portlet;

import org.exoplatform.cs.service.CSSpaceService;
import org.exoplatform.cs.service.EnvironmentService;
import org.exoplatform.cs.service.TicketService;
import org.exoplatform.services.listener.ListenerService;
import org.exoplatform.upload.UploadService;
